<?php

	/*
	* Plugin Name: Disallow WooCommerce Shipping to PO Box
	* Plugin URI: https://www.pluginhive.com/product/woocommerce-ups-shipping-plugin-with-print-label/
	* Description: This plugin will check for PO Box in WooCommerce Address Line 1 and 2 and disallow Shipping Methods if there is any PO Box Address.
	* Author: PluginHive
	* Author URI: https://pluginhive.com/
	* Version: 1.0.3
	* Text Domain: ph_prevent_ups_shiiping_to_po_box
	* Copyright: 2019 PluginHive.
	* WC requires at least: 3.0.0
	* WC tested up to: 5.3.0
	*/

	if ( ! defined( 'ABSPATH' ) ) {
		exit;
	}

	if ( !class_exists('WooCommerce') ) { 

		add_action( 'admin_init', 'ph_deactivate_prevent_shipping_to_po_box_plugin' );

		if ( ! function_exists( 'ph_deactivate_prevent_shipping_to_po_box_plugin' ) ) {

			function ph_deactivate_prevent_shipping_to_po_box_plugin() {

				if ( !class_exists('WooCommerce') ) {

					deactivate_plugins( plugin_basename( __FILE__ ) );
					wp_safe_redirect( admin_url('plugins.php') );
				}
			}
		}
	}

	function ph_prevent_shipping_to_po_box_activation_check() {

		if ( !is_plugin_active('woocommerce/woocommerce.php') ) {
			deactivate_plugins( basename( __FILE__ ) );
			wp_die( __("Oops! You tried installing the Hide UPS Shipping For PO Box Address without activating WooCommerce Plugin. Kindly activate <b>WooCommerce</b> and then try again", "ph_prevent_ups_shiiping_to_po_box" ), "", array('back_link' => 1 ));
		}
	}

	register_activation_hook( __FILE__, 'ph_prevent_shipping_to_po_box_activation_check' );

	function Ph_hide_ups_shipping_for_po_boxes() {

		if( !class_exists('PH_Prevent_UPS_Shipping_To_PO_Box_Address_Plugin') ){
			class PH_Prevent_UPS_Shipping_To_PO_Box_Address_Plugin extends WC_Shipping_Method{

				public $po_box_words 	= "PO BOX, PO-BOX, P.O. BOX, P.O BOX, PO. BOX";
				public $no_methods 		= false;

				public function __construct() {

					$this->id		= 'ph_disallow_ups_shipping_for_po_box';

					$this->method_title       = __( 'Disallow Shipping For PO Box', 'ph_prevent_ups_shiiping_to_po_box');
					$this->method_description = __( 'Enter PO Box name combinations for which you want to disallow WooCommerce Shipping Methods', 'ph_prevent_ups_shiiping_to_po_box');

					$this->init();

					$this->new_po_box_words = ( isset( $this->settings['ph_po_box_address'] ) && !empty( $this->settings['ph_po_box_address'] ) ) ? $this->settings['ph_po_box_address'] : $this->po_box_words;

					$this->additional_methods_to_hide = ( isset( $this->settings['ph_additional_methods'] ) && !empty( $this->settings['ph_additional_methods'] ) ) ? $this->settings['ph_additional_methods'] :'';

					$this->specific_methods_to_hide = ( isset( $this->settings['ph_specific_methods'] ) && !empty( $this->settings['ph_specific_methods'] ) ) ? $this->settings['ph_specific_methods'] :'';

					$this->custom_msg 	= ( isset( $this->settings['ph_custom_message'] ) && !empty( $this->settings['ph_custom_message'] ) ) ? $this->settings['ph_custom_message'] :'';

					add_filter( 'woocommerce_package_rates', array( $this, 'ph_hide_ups_shipping_based_on_string_in_address_lines'), 12, 2);

					add_filter( 'woocommerce_no_shipping_available_html', array( $this, 'ph_change_msg_when_no_shipping_options_available'), 10, 1 );

				}

				function init() {

					$this->init_form_fields();
					$this->init_settings();

					add_action( 'woocommerce_update_options_shipping_' . $this->id, array( $this, 'process_admin_options' ) );
				}

				function init_form_fields() {

					$this->form_fields = array(

						'ph_po_box_address' => array(
							'title'			=> __('PO Box Name Combination', 'ph_prevent_ups_shiiping_to_po_box'),
							'type'			=> 'textarea',
							'description'	=> __('1. Enter multiple PO Box Name Combinations seperated by Comma( , ). <br/> 2. Enter any PO Box combination you want to check or by default it will check for the following PO Box Name Combination.<br/>* PO BOX<br/> * PO-BOX<br/>* P.O. BOX<br/>* P.O BOX<br/>* PO. BOX','ph_prevent_ups_shiiping_to_po_box'),
							'desc_tip'		=> true,
							'css'			=> 'width: 50%;',
							'default'		=> $this->po_box_words,
							'placeholder'	=> $this->po_box_words,
						),

						'ph_additional_methods' => array(
							'title'			=> __('Grouped Shipping Methods', 'ph_prevent_ups_shiiping_to_po_box'),
							'type'			=> 'textarea',
							'description'	=> __("* By default this addon works with PluginHive UPS Shipping plugin<br/>* Enter shipping methods (Comma Seperated) above for which you want to extend this plugin's functionality",'ph_prevent_ups_shiiping_to_po_box'),
							'css'			=> 'width: 50%;',
							'placeholder'	=> 'Ex: flat_rate, free_shipping',
						),
						'ph_specific_methods' => array(
							'title'			=> __('Specific Shipping Methods', 'ph_prevent_ups_shiiping_to_po_box'),
							'type'			=> 'textarea',
							'description'	=> __("* By default this addon works with PluginHive UPS Shipping plugin<br/>* Enter specific shipping methods (Comma Seperated) above for which you want to extend this plugin's functionality",'ph_prevent_ups_shiiping_to_po_box'),
							'css'			=> 'width: 50%;',
							'placeholder'	=> 'Ex: flat_rate:01, free_shipping:02',
						),

						'ph_custom_message' => array(
							'title'			=> __('Custom Checkout Message', 'ph_prevent_ups_shiiping_to_po_box'),
							'type'			=> 'textarea',
							'description'	=> __("* If Custom message is empty, default message will be shown",'ph_prevent_ups_shiiping_to_po_box'),
							'css'			=> 'width: 50%;',
							'placeholder'	=> 'There are no shipping options available. Please ensure that your address has been entered correctly, or contact us if you need any help.',
						),
					);
				}

				function ph_change_msg_when_no_shipping_options_available( $default_msg ) {
					
					if( !$this->no_methods || empty( $this->custom_msg ) ) {

						return $default_msg;
					}
					
					return __( $this->custom_msg , 'ph_prevent_ups_shiiping_to_po_box');
				}

				public function ph_hide_ups_shipping_based_on_string_in_address_lines( $shipping_costs, $package )
				{
					$shipping_method_to_hide 	= array( 'wf_shipping_ups' );

					$address_line_one 			= strtolower( !empty( WC()->customer->get_shipping_address_1() ) ? WC()->customer->get_shipping_address_1()  : '' );
					$address_line_two 			= strtolower( !empty( WC()->customer->get_shipping_address_2() ) ? WC()->customer->get_shipping_address_2()  : '' );

					$needs_to_hide_ups				= false;

					$po_box_array = array_unique( explode(',', rtrim($this->new_po_box_words, ',') ) );

					foreach( $po_box_array as $word ) {
						
						if( strstr( $address_line_one, strtolower( trim($word) ) ) || strstr( $address_line_two, strtolower( trim($word) ) ) )
						{
							$needs_to_hide_ups = true;
							break;
						}
					}

					if( $needs_to_hide_ups && !empty($shipping_costs) )
					{

						$additional_methods_to_hide = explode(',', rtrim( str_replace(' ','',$this->additional_methods_to_hide), ',') );

						$specific_methods_to_hide  = explode(',', rtrim( str_replace(' ','',$this->specific_methods_to_hide), ',') );

						$specific_methods_to_hide 	= array_unique( $specific_methods_to_hide );

						if( !empty($additional_methods_to_hide) && is_array($additional_methods_to_hide) )
						{
							$shipping_method_to_hide 	= array_unique( array_merge($shipping_method_to_hide, $additional_methods_to_hide) );
						}
						
						foreach( $shipping_costs as $shipping_method => $shipping )
						{
							if( !empty($shipping_method_to_hide) && is_array($shipping_method_to_hide) && in_array( $shipping->get_method_id(), $shipping_method_to_hide) ) {
								unset($shipping_costs[$shipping_method]);
							}
							
							if( !empty($specific_methods_to_hide) && is_array($specific_methods_to_hide) && in_array( $shipping->get_id(), $specific_methods_to_hide) ) {
	                            unset($shipping_costs[$shipping_method]);
	                        }  
						}

						if( empty($shipping_costs) )
						{
							$this->no_methods = true;
						}
					}

					return $shipping_costs;
				}

			}

		}
	}

	add_action( 'woocommerce_shipping_init', 'Ph_hide_ups_shipping_for_po_boxes' );

	function add_ph_prevent_to_po_box_plugin( $methods ) {
		$methods['Ph_hide_ups_shipping_for_po_boxes'] = 'PH_Prevent_UPS_Shipping_To_PO_Box_Address_Plugin';
		return $methods;
	}

	add_filter( 'woocommerce_shipping_methods', 'add_ph_prevent_to_po_box_plugin' );

	/* Create a Settings link */
	function ph_prevent_ship_to_po_box_settings_link( $links ) 
	{
		$settings_link = '<a href="admin.php?page=wc-settings&tab=shipping&section=ph_disallow_ups_shipping_for_po_box">Settings</a>';
		array_push( $links, $settings_link );
		return $links;
	}

	add_filter( "plugin_action_links_".plugin_basename(__FILE__), 'ph_prevent_ship_to_po_box_settings_link');